Title: Does General Intelligence Deflate Standardized Effect Sizes of Cognitive Sex Differences?
Date: 2020-10-01 05:00
Category: commentary
Tags: statistics
Status: draft

(SEXNET's own) Marco del Guidice points out[^mdg] that in the presence of measurement error, standardized effect size measures like [Cohen's _d_](https://rpsychologist.com/d3/cohend/) will underestimate the "true" effect size. Recall that _d_ is the difference in group means, divided by the pooled variance. Thus, holding _actual_ sex differences constant, more measurement error means more variance, which means smaller values of _d_. Here's some toy Python code illustrating this effect:

[^mdg]: Marco del Guidice, ["Measuring Sex Differences and Similarities"](https://marcodgdotnet.files.wordpress.com/2019/04/delgiudice_measuring_sex-differences-similarities_pre.pdf)

```python
from math import sqrt
from statistics import mean, variance

from numpy.random import normal, seed

# seed the random number generator for reproducibility of given figures,
# commment this out to run a new experiment
seed(1)

def cohens_d(X, Y):
    return (
        (mean(X) + mean(Y)) /
        sqrt(
            (len(X)*variance(X) + len(Y)*variance(Y)) /
            (len(X) + len(Y))
        )
    )

def population_with_error(μ, σ, n):
    def trait():
        return normal(μ, 1)
    def measurement_error():
        return normal(0, σ)
    return [trait() + measurement_error() for _ in range(n)]


# trait differs by 1 standard deviation
adjusted_f = population_with_error(1, 0, 10000)
adjusted_m = population_with_error(0, 0, 10000)

# as above, but with 0.5 standard units measurment error
measured_f = population_with_error(1, 0.5, 10000)
measured_m = population_with_error(0, 0.5, 10000)

smart_d = cohens_d(adjusted_f, adjusted_m)
print(smart_d)  # 1.0193773432617055 — d≈1.0, as expected!

naïve_d = cohens_d(measured_f, measured_m)
print(naïve_d)  # 0.8953395386313235
```

But doesn't a similar argument hold for non-error sources of variance that are "orthogonal" to the group difference? (Sorry, I know this is vague; I'm writing to the list in case any Actual Scientists can spare a moment to help me make my intuition more precise.) Like, suppose performance on some particular cognitive task can be modeled as the sum of the general intelligence factor (zero or negligible sex difference[^jensen]), and a special ability factor that does show sex differences. Then, even with zero _measurement_ error, _d_ would underestimate the difference between women and men _of the same general intelligence_.

[^jensen]: Arthur Jensen, _The g Factor_, Chapter 13

```python
def performance(g, σ_g, s, n):
    def general_ability():
        return normal(g, σ_g)
    def special_ability():
        return normal(s, 1)
    return [general_ability() + special_ability() for _ in range(n)]

# ♀ one standard deviation better than ♂ at the special factor
population_f = performance(0, 1, 1, 10000)
population_m = performance(0, 1, 0, 10000)

# ... but suppose we control/match for general intelligence
matched_f = performance(0, 0, 1, 10000)
matched_m = performance(0, 0, 0, 10000)

population_d = cohens_d(population_f, population_m)
print(population_d)  # 0.7287587808164793

matched_d = cohens_d(matched_f, matched_m)
print(matched_d)  # 1.018362581243161
```
